﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;

namespace CsFileCopy
{
    /// <summary>
    /// 抽出結果をファイルに出力するためのダイアログです。
    /// </summary>
    public partial class ResultOutputDialog : Form
    {
        private MainWindow parent;
        private DataTable dataTable;

        /// <summary>
        /// 結果出力ダイアログを作成します。
        /// </summary>
        /// <param name="dt">抽出結果</param>
        public ResultOutputDialog(MainWindow parent, DataTable dt)
        {
            InitializeComponent();

            this.parent = parent;
            this.dataTable = dt;
        }

        /// <summary>
        /// 結果をファイルに出力ボタンクリック時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void outputButton_Click(object sender, EventArgs e)
        {
            // 出力対象の項目が選択されていない場合
            if (!filePathBox.Checked && !updateDateBox.Checked)
            {
                MessageUtil.ShowAlert("出力項目が選択されていません。");
                return;
            }

            // データグリッドビューへの編集を終了させる
            parent.EndDataGridViewEdit();

            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    StreamWriter writer = new StreamWriter(saveFileDialog1.FileName, false, Encoding.GetEncoding("Shift_JIS"));

                    foreach (DataRow row in dataTable.Rows)
                    {
                        // チェックされているもののみ出力する場合
                        if (checkedRadio.Checked)
                        {
                            bool checkedItem = (bool)row[0];

                            // チェックされていない行は出力しない
                            if (!checkedItem)
                            {
                                continue;
                            }
                        }

                        // ファイルパスが出力対象
                        if (filePathBox.Checked)
                        {
                            writer.Write(row[2] + "\\" + row[1]);
                        }

                        // ファイルパスと更新日時が出力対象
                        if (filePathBox.Checked && updateDateBox.Checked)
                        {
                            if (commaRadio.Checked)
                            {
                                writer.Write(",");
                            }
                            else
                            {
                                writer.Write("\t");
                            }
                        }

                        // 更新日時が出力対象
                        if (updateDateBox.Checked)
                        {
                            writer.Write(row[3]);
                        }

                        writer.WriteLine();
                    }

                    writer.Close();

                    MessageUtil.ShowInfo("結果をファイルに出力しました。");
                }
                catch (Exception ex)
                {
                    Log.GetInstance().Error(ex.Message);
                    Log.GetInstance().Error(ex.StackTrace);

                    MessageUtil.ShowAlert("ファイルの出力に失敗しました。\n" + ex.Message);
                }

                Close();
            }
        }

        private void ResultOutputDialog_Load(object sender, EventArgs e)
        {

        }
    }
}
